;
; display-all-buffers.el
;
; Emacs lisp routine that renders multiple files specified on
; the command line in a somewhat more intuitive and useful manner
; than is presently done by GNU Emacs...
;
;
; This project was sponsored by the
; Open Source Financial Developers Association (OSFDA)
;
;      http://osfda.org
;
; A download _might_ be available from http://osfda.org/downloads
;
;
; LICENSE: GPL2
;
; This work is free software; you can redistribute it and/or modify it
; under the terms of the GNU General Public License as published
; by the Free Software Foundation; either version 2 of the License, or
; any later version. This work is distributed in the hope that it will be
; useful, but without any warranty; without even the implied warranty
; of merchantability or fitness for a particular purpose.
;
(defun display-all-buffers()
"
Overrides (GNU) Emacs behavior of loading multiple files on the command line
as just two windows: the first file and a scratch buffer of the files loaded.
each file on the command line is instead loaded in its own window,
and the cursor is left 'parked' in the window of the first file specified
(a more intuitive behavior...)

Sponsored by the Open Source Financial Developers Association
"
 (interactive)
 (delete-other-windows)
 (let* ((window 1)
        (WINDOW-TITLE-BAR-HEIGHT 1)
        (MIN-LINES-PER-WINDOW 2)
        (lines (+ (window-body-height) WINDOW-TITLE-BAR-HEIGHT))
        (max-windows (/ lines MIN-LINES-PER-WINDOW))
       )
       (catch 'dolist-buffer
              ;; since list insertion is at the head,
              ;; buffer-list will have the file buffers in reverse order...
              (dolist (buffer (reverse (buffer-list)))
                      (when (buffer-file-name buffer) ; not a "scratch" buffer...
                            (when (> window 1) ; need a new window? (1st time: no...)
                                  (split-window)
                                  (if (> window 2)
                                      (balance-windows)
                                  )
                                  ;; load the next window in the same order
                                  ;; as the command line argument...
                                  (select-window (next-window))
                            ) ; when (> window 1)
                            (set-window-buffer (selected-window) buffer)
                            (if (= window max-windows)
                                (throw 'dolist-buffer window)
                            )
                            (setq window (+ window 1))
                      ) ; when (buffer-file-name buffer)
              ) ; dolist buffer
       ) ; catch 'dolist-buffer
 ) ; let*
 ;; will be on the last window; park on the first...
 (select-window (next-window))
) ; display-all-buffers()

(let ((APPEND t))
     (add-hook 'emacs-startup-hook
               (lambda ()
                       (display-all-buffers)
               )
               APPEND
     )
)
